/*jshint esnext: true*/

'use strict';

/**
  @ngdoc directive
  @name panel-toggle
  @restrict E
  @description
  Open/Hide content in a panel-heading
  ### Example
  <panel-toggle is-open="false"></panel-toggle>
*/

var realBoolean = function (val) {
  return val == 'true' ? true : (
    val == 'false' ? false : val
  );
};

var closedClass = 'panel-closed';

module.exports = ['$timeout', function ($timeout) {
  return {
    restrict: 'E',
    template: `
      <button class="btn btn-xs btn-default" ng-click="onClick()">
        <i class="fa" ng-class="{
          'fa-minus': isOpen,
          'fa-plus': !isOpen
        }"></i>
      </button>
    `,
    scope: {
      isOpen: '='
    },
    link: function (scope, element, attrs) {
      var isOpen = function () {
        return 'isOpen' in scope ? realBoolean(scope.isOpen) : true;
      };

      scope.onClick = function () {
        scope.isOpen = !isOpen();
        showHide();
      };
      scope.$watch('isOpen', showHide);

      function showHide () {
        var fn = isOpen() ? 'removeClass' : 'addClass';
        element.parents('.panel')[fn](closedClass);
      }
    }
  };
}];
